@@ -42,7 +42,8 @@ by creating an instance of PersistentDB, passing the following parameters:
         prepare the session, e.g. ["set datestyle to german", ...].
     failures: an optional exception class or a tuple of exception classes
         for which the connection failover mechanism shall be applied,
-        if the default (OperationalError, InternalError) is not adequate
+        if the default (OperationalError, InterfaceError, InternalError)
+        is not adequate for the used database module
     ping: an optional flag controlling when connections are checked
         with the ping() method if such a method is available
         (0 = None = never, 1 = default = whenever it is requested,
@@ -155,7 +156,8 @@ class PersistentDB:
             the session, e.g. ["set datestyle to ...", "set time zone ..."]
         failures: an optional exception class or a tuple of exception classes
             for which the connection failover mechanism shall be applied,
-            if the default (OperationalError, InternalError) is not adequate
+            if the default (OperationalError, InterfaceError, InternalError)
+            is not adequate for the used database module
         ping: determines when the connection should be checked with ping()
             (0 = None = never, 1 = default = whenever it is requested,
             2 = when a cursor is created, 4 = when a query is executed,
